BlockLogs

Struct BlockLogs 

pub struct BlockLogs<N: Network> {
    pub block: N::BlockResponse,
    pub logs: Vec<Log>,
}
Logs matching a filter for a single block.

This is the payload resolved by BlockLogsFut and carried by canonical log events. The block field identifies the block whose logs were queried, and logs contains all matching logs for that block. logs may be empty when the block contained no matching logs.

Fields

block: N::BlockResponse

The block these logs belong to.

logs: Vec<Log>

Logs matching the configured filter for block.

Implementations

Source

impl<N: Network> BlockLogs<N>

pub fn header(&self) -> &N::HeaderResponse

Returns the header for the block these logs belong to.