pub struct CcipReadClient<G> { /* private fields */ }Available on crate feature
ccip-read only.Expand description
Executes eth_call requests that follow ERC-3668 OffchainLookup reverts.
Implementations
Sourceimpl<G> CcipReadClient<G>
impl<G> CcipReadClient<G>
Sourcepub const fn with_config(self, config: CcipReadConfig) -> Self
pub const fn with_config(self, config: CcipReadConfig) -> Self
Sets the limits used by this client.
Sourcepub const fn config(&self) -> &CcipReadConfig
pub const fn config(&self) -> &CcipReadConfig
Returns the configured limits.
Sourceimpl<G: CcipReadGateway> CcipReadClient<G>
impl<G: CcipReadGateway> CcipReadClient<G>
Sourcepub async fn call<P, N>(
&self,
provider: &P,
transaction: N::TransactionRequest,
) -> Result<Bytes, CcipReadError>
pub async fn call<P, N>( &self, provider: &P, transaction: N::TransactionRequest, ) -> Result<Bytes, CcipReadError>
Executes a CCIP Read enabled call against the latest block.
Sourcepub async fn call_at<P, N>(
&self,
provider: &P,
transaction: N::TransactionRequest,
block: BlockId,
) -> Result<Bytes, CcipReadError>
pub async fn call_at<P, N>( &self, provider: &P, transaction: N::TransactionRequest, block: BlockId, ) -> Result<Bytes, CcipReadError>
Executes a CCIP Read enabled call against block.
The initial call and every callback call are issued against block. With a block tag such
as latest, the underlying state can move between those calls while gateway requests are
in flight.