pub struct CcipReadGatewayError {
pub status: Option<u16>,
pub message: String,
}Available on crate feature
ccip-read only.Expand description
An error returned while fetching data from a CCIP Read gateway.
Fields
status: Option<u16>HTTP status, when the failure came from an HTTP response.
message: StringA human-readable description of the failure.
Implementations