pub struct Dynamic<D: SolCall>(/* private fields */);Expand description
Marker for Dynamic Calls i.e where in SolCall type is locked to one specific type and multicall returns a Vec of the corresponding return type instead of a tuple.