EthGetBlock

Struct EthGetBlock 

pub struct EthGetBlock<BlockResp>
where BlockResp: BlockResponse + RpcRecv,
{ /* private fields */ }
A builder for an "eth_getBlockByHash" request. This type is returned by the Provider::call method.

Implementations

Source

impl<BlockResp> EthGetBlock<BlockResp>
where BlockResp: BlockResponse + RpcRecv,

pub fn by_hash(hash: BlockHash, client: ClientRef<'_>) -> Self

Create a new EthGetBlock request to get the block by hash i.e call "eth_getBlockByHash".

pub fn by_number(number: BlockNumberOrTag, client: ClientRef<'_>) -> Self

Create a new EthGetBlock request to get the block by number i.e call "eth_getBlockByNumber".

Source

impl<BlockResp> EthGetBlock<BlockResp>
where BlockResp: BlockResponse + RpcRecv,

pub fn new_rpc( block: BlockId, inner: RpcCall<EthGetBlockParams, Option<BlockResp>>, ) -> Self

Create a new EthGetBlock request with the given RpcCall.

pub fn new_pending_rpc(inner: RpcCall<EthGetBlockParams, Value>) -> Self

Create a new EthGetBlock request with the given RpcCall for pending block.

pub fn new_provider( block: BlockId, producer: Box<dyn Fn(BlockTransactionsKind) -> ProviderCall<EthGetBlockParams, Option<BlockResp>> + Send>, ) -> Self

Create a new EthGetBlock request with a closure that returns a ProviderCall.

pub const fn kind(self, kind: BlockTransactionsKind) -> Self

Set the BlockTransactionsKind for the request.

pub const fn full(self) -> Self

pub const fn hashes(self) -> Self