pub struct GetSubscription<P, R>{ /* private fields */ }Available on crate feature
pubsub only.Expand description
A general-purpose subscription request builder
This struct allows configuring subscription parameters and channel size before initiating a request to subscribe to Ethereum events.
Implementations
Sourceimpl<P, R> GetSubscription<P, R>
impl<P, R> GetSubscription<P, R>
Sourcepub fn new(client: WeakClient, call: RpcCall<P, B256>) -> Self
pub fn new(client: WeakClient, call: RpcCall<P, B256>) -> Self
Creates a new GetSubscription instance
Sourcepub const fn channel_size(self, size: usize) -> Self
pub const fn channel_size(self, size: usize) -> Self
Set the channel_size for the subscription stream.