pub struct WsConnect { /* private fields */ }ws-base only.Expand description
Simple connection details for a websocket connection.
Implementations
Sourceimpl WsConnect
impl WsConnect
Sourcepub fn new<S>(url: S) -> WsConnect
pub fn new<S>(url: S) -> WsConnect
Creates a new websocket connection configuration.
If the URL contains credentials (e.g. wss://user:pass@host), they are
automatically extracted and set as the Authorization header.
Sourcepub fn with_auth(self, auth: Authorization) -> WsConnect
pub fn with_auth(self, auth: Authorization) -> WsConnect
Sets the authorization header.
Sourcepub fn with_auth_opt(self, auth: Option<Authorization>) -> WsConnect
pub fn with_auth_opt(self, auth: Option<Authorization>) -> WsConnect
Sets the optional authorization header.
This replaces the current Authorization.
Sourcepub const fn with_config(self, config: WebSocketConfig) -> WsConnect
pub const fn with_config(self, config: WebSocketConfig) -> WsConnect
Sets the websocket config.
Sourcepub const fn auth(&self) -> Option<&Authorization>
pub const fn auth(&self) -> Option<&Authorization>
Get the authorization header.
Sourcepub const fn config(&self) -> Option<&WebSocketConfig>
pub const fn config(&self) -> Option<&WebSocketConfig>
Get the websocket config.
Sourcepub const fn with_max_retries(self, max_retries: u32) -> WsConnect
pub const fn with_max_retries(self, max_retries: u32) -> WsConnect
Sets the max number of retries before failing and exiting the connection. Default is 10.
Sourcepub const fn with_retry_interval(self, retry_interval: Duration) -> WsConnect
pub const fn with_retry_interval(self, retry_interval: Duration) -> WsConnect
Sets the base interval between retries.
Reconnect retries use capped exponential backoff from this base interval. Default is 3 seconds.
Sourcepub const fn with_keepalive_interval(
self,
keepalive_interval: Duration,
) -> WsConnect
pub const fn with_keepalive_interval( self, keepalive_interval: Duration, ) -> WsConnect
Sets the keepalive ping interval.
A ping is sent if no other messages have been sent within this interval. If the server does not respond with a pong before the next ping is due, the connection is considered dead and will be closed.
Default is 10 seconds.