pub struct CacheLayer { /* private fields */ }target_family=wasm only.Expand description
A provider layer that caches RPC responses and serves them on subsequent requests.
In order to initialize the caching layer, the path to the cache file is provided along with the max number of items that are stored in the in-memory LRU cache.
One can load the cache from the file system by calling load_cache and save the cache to the
file system by calling save_cache.
Implementations
Sourceimpl CacheLayer
impl CacheLayer
Sourcepub fn new(max_items: u32) -> Self
pub fn new(max_items: u32) -> Self
Instantiate a new cache layer with the maximum number of items to store.
Sourcepub const fn max_items(&self) -> u32
pub const fn max_items(&self) -> u32
Returns the maximum number of items that can be stored in the cache, set at initialization.
Sourcepub fn cache(&self) -> SharedCache
pub fn cache(&self) -> SharedCache
Returns the shared cache.