pub struct CacheProvider<P, N> { /* private fields */ }Available on non-
target_family=wasm only.Expand description
The CacheProvider holds the underlying in-memory LRU cache and overrides methods
from the Provider trait. It attempts to fetch from the cache and fallbacks to
the RPC in case of a cache miss.
Most importantly, the CacheProvider adds save_cache and load_cache methods
to the provider interface, allowing users to save the cache to disk and load it
from there on demand.
Implementations
Sourceimpl<P, N> CacheProvider<P, N>
impl<P, N> CacheProvider<P, N>
Sourcepub const fn new(inner: P, cache: SharedCache) -> Self
pub const fn new(inner: P, cache: SharedCache) -> Self
Instantiate a new cache provider.