pub struct EthGetBlock<BlockResp>where
BlockResp: BlockResponse + RpcRecv,{ /* private fields */ }Expand description
A builder for an "eth_getBlockByHash" request. This type is returned by the
Provider::call method.
Implementations
Sourceimpl<BlockResp> EthGetBlock<BlockResp>where
BlockResp: BlockResponse + RpcRecv,
impl<BlockResp> EthGetBlock<BlockResp>where
BlockResp: BlockResponse + RpcRecv,
Sourcepub fn by_hash(hash: BlockHash, client: ClientRef<'_>) -> Self
pub fn by_hash(hash: BlockHash, client: ClientRef<'_>) -> Self
Create a new EthGetBlock request to get the block by hash i.e call
"eth_getBlockByHash".
Sourcepub fn by_number(number: BlockNumberOrTag, client: ClientRef<'_>) -> Self
pub fn by_number(number: BlockNumberOrTag, client: ClientRef<'_>) -> Self
Create a new EthGetBlock request to get the block by number i.e call
"eth_getBlockByNumber".
Sourceimpl<BlockResp> EthGetBlock<BlockResp>where
BlockResp: BlockResponse + RpcRecv,
impl<BlockResp> EthGetBlock<BlockResp>where
BlockResp: BlockResponse + RpcRecv,
Sourcepub fn new_rpc(
block: BlockId,
inner: RpcCall<EthGetBlockParams, Option<BlockResp>>,
) -> Self
pub fn new_rpc( block: BlockId, inner: RpcCall<EthGetBlockParams, Option<BlockResp>>, ) -> Self
Create a new EthGetBlock request with the given RpcCall.
Sourcepub fn new_pending_rpc(inner: RpcCall<EthGetBlockParams, Value>) -> Self
pub fn new_pending_rpc(inner: RpcCall<EthGetBlockParams, Value>) -> Self
Create a new EthGetBlock request with the given RpcCall for pending block.
Sourcepub fn new_provider(
block: BlockId,
producer: Box<dyn Fn(BlockTransactionsKind) -> ProviderCall<EthGetBlockParams, Option<BlockResp>> + Send>,
) -> Self
pub fn new_provider( block: BlockId, producer: Box<dyn Fn(BlockTransactionsKind) -> ProviderCall<EthGetBlockParams, Option<BlockResp>> + Send>, ) -> Self
Create a new EthGetBlock request with a closure that returns a ProviderCall.
Sourcepub const fn kind(self, kind: BlockTransactionsKind) -> Self
pub const fn kind(self, kind: BlockTransactionsKind) -> Self
Set the BlockTransactionsKind for the request.
Sourcepub const fn full(self) -> Self
pub const fn full(self) -> Self
Set the BlockTransactionsKind to BlockTransactionsKind::Full.
Sourcepub const fn hashes(self) -> Self
pub const fn hashes(self) -> Self
Set the BlockTransactionsKind to BlockTransactionsKind::Hashes.