pub struct RootProvider<N: Network = Ethereum> { /* private fields */ }Expand description
The root provider manages the RPC client and the heartbeat. It is at the base of every provider stack.
Implementations
Sourceimpl<N: Network> RootProvider<N>
impl<N: Network> RootProvider<N>
Sourcepub fn new_http(url: Url) -> Self
Available on crate feature reqwest only.
pub fn new_http(url: Url) -> Self
reqwest only.Creates a new HTTP root provider from the given URL.
Sourcepub async fn connect(s: &str) -> Result<Self, TransportError>
pub async fn connect(s: &str) -> Result<Self, TransportError>
Creates a new root provider from the provided string.
See BuiltInConnectionString for more information.
Sourcepub async fn connect_builtin(s: &str) -> Result<Self, TransportError>
👎Deprecated since 0.9.0: use connect instead
pub async fn connect_builtin(s: &str) -> Result<Self, TransportError>
connect insteadCreates a new root provider from the provided connection details.
Sourcepub async fn connect_with<C: TransportConnect>(
conn: C,
) -> Result<Self, TransportError>
pub async fn connect_with<C: TransportConnect>( conn: C, ) -> Result<Self, TransportError>
Connects to a transport with the given connector.
Sourcepub async fn connect_boxed<C: TransportConnect>(
conn: C,
) -> Result<Self, TransportError>
👎Deprecated since 0.9.0: RootProvider is now always boxed, use connect_with instead
pub async fn connect_boxed<C: TransportConnect>( conn: C, ) -> Result<Self, TransportError>
RootProvider is now always boxed, use connect_with insteadConnects to a boxed transport with the given connector.
Sourceimpl<N: Network> RootProvider<N>
impl<N: Network> RootProvider<N>
Sourcepub fn boxed(self) -> Self
👎Deprecated since 0.9.0: RootProvider is now always boxed
pub fn boxed(self) -> Self
RootProvider is now always boxedBoxes the inner client.
Sourcepub async fn get_subscription<R: RpcRecv>(
&self,
id: B256,
) -> TransportResult<Subscription<R>>
Available on crate feature pubsub only.
pub async fn get_subscription<R: RpcRecv>( &self, id: B256, ) -> TransportResult<Subscription<R>>
pubsub only.Gets the subscription corresponding to the given RPC subscription ID.
Sourcepub fn unsubscribe(&self, id: B256) -> TransportResult<()>
Available on crate feature pubsub only.
pub fn unsubscribe(&self, id: B256) -> TransportResult<()>
pubsub only.Unsubscribes from the subscription corresponding to the given RPC subscription ID.