pub struct WatchBlocks<BlockResp> { /* private fields */ }Expand description
A builder type for polling new blocks using the FilterPollerBuilder.
By default, this polls for blocks with BlockTransactionsKind::Hashes.
WatchBlocks::full should be used to poll for blocks with
BlockTransactionsKind::Full.
The polling stream must be consumed by calling WatchBlocks::into_stream.
Implementations
Sourceimpl<BlockResp> WatchBlocks<BlockResp>where
BlockResp: BlockResponse + RpcRecv,
impl<BlockResp> WatchBlocks<BlockResp>where
BlockResp: BlockResponse + RpcRecv,
Sourcepub const fn full(self) -> Self
pub const fn full(self) -> Self
Poll for blocks with full transactions i.e BlockTransactionsKind::Full.
Sourcepub const fn hashes(self) -> Self
pub const fn hashes(self) -> Self
Poll for blocks with just transactions hashes i.e BlockTransactionsKind::Hashes.
Sourcepub const fn set_channel_size(&mut self, channel_size: usize)
pub const fn set_channel_size(&mut self, channel_size: usize)
Sets the channel size for the poller task.
Sourcepub fn set_limit(&mut self, limit: Option<usize>)
pub fn set_limit(&mut self, limit: Option<usize>)
Sets a limit on the number of successful polls.
Sourcepub const fn set_poll_interval(&mut self, poll_interval: Duration)
pub const fn set_poll_interval(&mut self, poll_interval: Duration)
Sets the duration between polls.
Sourcepub fn into_stream(
self,
) -> impl Stream<Item = TransportResult<BlockResp>> + Unpin
pub fn into_stream( self, ) -> impl Stream<Item = TransportResult<BlockResp>> + Unpin
Consumes the stream of block hashes from the inner FilterPollerBuilder and maps it to a
stream of BlockResponse.