pub struct WatchBlocksFrom<N: Network> { /* private fields */ }Expand description
A builder for streaming blocks from a historical block and continuing indefinitely.
Implementations
Sourceimpl<N: Network> WatchBlocksFrom<N>
impl<N: Network> WatchBlocksFrom<N>
Sourcepub const fn poll_interval(self, poll_interval: Duration) -> Self
pub const fn poll_interval(self, poll_interval: Duration) -> Self
Sets the poll interval used when the stream is caught up.
Sourcepub const fn block_tag(self, block_tag: BlockNumberOrTag) -> Self
pub const fn block_tag(self, block_tag: BlockNumberOrTag) -> Self
Sets the head block tag used to determine stream progress.
Sourcepub const fn canonical(self) -> WatchCanonicalBlocksFrom<N>
pub const fn canonical(self) -> WatchCanonicalBlocksFrom<N>
Converts this builder into a canonical-stream builder that emits
crate::CanonicalEvent deltas on reorgs.
Sourcepub const fn into_stream(self) -> WatchBlocksFromStream<N>
pub const fn into_stream(self) -> WatchBlocksFromStream<N>
Stream blocks from a historical block using sequential eth_getBlockByNumber calls.
This stream continues polling after catching up and continues yielding new blocks indefinitely.
This stream does not handle reorgs. Instead, each item yielded from the stream is strictly ordered in terms of block number, regardless of the blocks parent.
For example (height, hash, parent):
You should expect blocks in order by number with no gaps and with disjoint parents: [(1, 1A, 0A),(2, 2A, 1A),(3,3B,2B)]
And you should not expect receiving two blocks with the same number: [(1, 1A, 0A),(2, 2A, 1A),(2,2B,1A)]
Each yielded future contains one block request.
If a block request returns NullResp, the yielded future retries the same block until it
succeeds.
Other errors are surfaced to the caller. Configure retries on the underlying client
transport (for example with RetryBackoffLayer) for transport-level retry behavior.
This can be buffered by the caller, for example with
StreamExt::buffered.